clear all
set maxvar 80000
set matsize 11000
set more off
capture log close
global dir "/DV-Gender-Differences/Travel-Patterns"
use "$dir/booking_ana_data_v2.dta"
local outcomevar paid_fare_usd
local group1a 	"lengthb direct routeclass weekstarttrip"
local group1b 	"divisionid countryb" 
local group2 	"ntripb ageb emptype" 
local group2i 	"i.ntripb i.ageb i.emptype"
local group3 	"bookbin" 
local group3i 	"i.bookbin"
* Main sample
timer on 1
reghdfe `outcomevar' female i.lengthb direct, absorb(routeclass weekstarttrip divisionid countryb)
timer off 1
timer list 1
timer clear 1
gen sample = e(sample)
save "$dir/booking_ana_data_v2_sample.dta", replace
* Sample preference data
use "$dir/booking_ana_data_v2_sample.dta", clear
local outcomevar paid_fare_usd
local ticketcov "i.lengthb direct"
local ticketcovdrop "*.lengthb direct"
local routeFE "routeclass"
local group1a 	"lengthb direct routeclass weekstarttrip"
local group1b 	"divisionid countryb" 
local group2 	"ntripb ageb emptype" 
local group2i 	"i.ntripb i.ageb i.emptype"
local group3 	"bookbin" 
local group3i 	"i.bookbin"

timer on 1
reghdfe `outcomevar' female i.ntripb i.ageb `ticketcov' i.emptype if pref_data==1, absorb(`routeFE' countryb weekstarttrip divisionid) vce(cluster countryb)
gen sample_pref = e(sample)
timer off 1
timer list 1
timer clear 1

save "$dir/booking_ana_data_v2_sample-pref.dta", replace
* Sum Stats
use "$dir/booking_ana_data_v2_sample-pref.dta", clear
log using sum-stats-pwcorr.log, replace
* Dependent Variables
sum paid_fare_usd 			if sample==1, d
sum paid_fare_usd 			if sample==1 & female==1, d
sum paid_fare_usd 			if sample==1 & female==0, d
sum bookadvance 			if sample==1, d
sum bookadvance				if sample==1 & female==1, d
sum bookadvance 			if sample==1 & female==0, d
sum fourteen_days_prior		if sample==1, d
sum fourteen_days_prior		if sample==1 & female==1, d
sum fourteen_days_prior		if sample==1 & female==0, d
sum seven_days_prior		if sample==1 & female==0
* Independent Variables
tab female 					if sample==1
tab direct female 			if sample==1
tab direct 		 			if sample==1
tab ageb female 			if sample==1
tab ageb					if sample==1
tab lengthb female 			if sample==1
tab lengthb    				if sample==1
tab ntripb female 			if sample==1
tab ntripb 		 			if sample==1
tab ticketclass female 		if sample==1
tab ticketclass 			if sample==1
tab bkg_trip_type female 	if sample==1
tab bkg_trip_type 	 		if sample==1
tab region_code female 		if sample==1
tab region_code  	 		if sample==1
* Preference data
* Pairwise correlation coefficients for preference data
pwcorr fpatience frisktaking faltruism fposreciprocity fnegreciprocity ftrust 	if sample_pref==1
*Sum stats preference data
sum patience risktaking altruism posreciprocity negreciprocity trust 			if sample_pref==1
log close
