* This do-file replicates Replicates Tables 4, 6, 7 and A12 through A23. 
* local variable "estoutcome" is used to call the dependent variable in 
* the different tables. Local variables "ticketcov", "ticketcovdrop" and
* "routeF" are used for different covariates in the specfications. 
clear all
set more off
capture log close
global dir "/DV-Gender-Differences/Travel-Patterns"
local estoutcome = `1'
use "$dir/booking_ana_data_v2.dta"
*For testing: use 1% subsample
if ("`testing'"=="test") {
 sample 1
}

local ticketcov "i.lengthb direct"
local ticketcovdrop "*.lengthb direct"
local routeFE "routeclass"
* Testing
if (`estoutcome'==0) {
 local outcomevar paid_fare_usd
 local outcomename "Paid fare test"
 sample 1
}
* Paid fare by gender
if (`estoutcome'==1) {
 local outcomevar paid_fare_usd
 local outcomename "Paid fare"
}
// Days booked in advance
if (`estoutcome'==2) {
local outcomevar bookadvance
local outcomename "Days booked in advance"
}
// Probability for booking one week
if (`estoutcome'==3) {
local outcomevar seven_days_prior
local outcomename "Probability model for booking one week in advance"
}
// Probability for booking two weeks
if (`estoutcome'==4) {
local outcomevar fourteen_days_prior
local outcomename "Probability model for booking two weeks in advance"
}
// Probability for booking three weeks
if (`estoutcome'==5) {
local outcomevar twenty1_days_prior 
local outcomename "Probability model for booking three weeks in advance"
}
// Probability for booking four weeks
if (`estoutcome'==6) {
local outcomevar twenty8_days_prior
local outcomename "Probability model for booking four weeks in advance"
}
// Booking first, business, or premium economy classes
if (`estoutcome'==7) {
local outcomevar premticket
local outcomename "Probability model for booking premium ticket"
local routeFE "routeid"
}
// Booking direct flight
if (`estoutcome'==8) {
local outcomevar direct
local outcomename "Probability model for booking direct flight"
local ticketcov "i.lengthb"
local ticketcovdrop "*.lengthb"
}
log using "$dir/log_ana_`outcomevar'_v2`testing'", text replace

timer on 1
reghdfe `outcomevar' female `ticketcov', absorb(`routeFE' weekstarttrip divisionid countryb)
eststo est3
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
gen sample = e(sample)
tab sample

reg `outcomevar' female if sample==1
eststo est1
quietly estadd scalar adjR2 = e(r2_a)

timer on 1
reghdfe `outcomevar' female `ticketcov' if sample==1, fast absorb(`routeFE' weekstarttrip)
eststo est2
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1

timer on 1
reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1, fast absorb(`routeFE' weekstarttrip divisionid countryb) 
eststo est4
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1

*Create list of models to display. Will depend on outcome. 
local estlist "est1 est2 est3 est4"

*Don't include bookbin specification if outcome is advanced booking
if ((`estoutcome'<2)|(`estoutcome'>6)) {
 timer on 1
 reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1, fast absorb(`routeFE' weekstarttrip divisionid countryb bookbin)
 eststo est5
 quietly estadd scalar adjR2 = e(r2_a)
 timer off 1
 timer list 1
 timer clear 1
 local estlist "est1 est2 est3 est4 est5"
}
esttab `estlist', se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
esttab `estlist' using "$dir/Tables/Table_`outcomevar'_v2`testing'.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
    title(`outcomename' by Gender\label{tab`outcomevar'}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
    eststo clear

*** Interaction tables
foreach var in fageb flengthb {
timer on 1
eststo: reghdfe `outcomevar' i.`var' i.ntripb i.ageb `ticketcov' i.emptyp, fast absorb(`routeFE' countryb weekstarttrip divisionid) 
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
}
esttab, se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype)
esttab using "$dir/Tables/Table_`outcomevar'_int1_v2`testing'.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
        title(`outcomename': female interactions (part I)\label{tab`outcomevar'_int1}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype)
eststo clear

foreach var in fntripb fregionb {
  timer on 1
  eststo: reghdfe `outcomevar' i.`var' i.ntripb i.ageb `ticketcov' i.emptyp, fast absorb(`routeFE' countryb weekstarttrip divisionid) 
  quietly estadd scalar adjR2 = e(r2_a)
  timer off 1
  timer list 1
  timer clear 1
}
esttab, se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype )
esttab using "$dir/Tables/Table_`outcomevar'_int2_v2`testing'.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
    title(`outcomename': female interactions (part II)\label{tab`outcomevar'_int2}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype)
eststo clear

* Preference interactions tables
timer on 1
eststo: reghdfe `outcomevar' female i.ntripb i.ageb `ticketcov' i.emptype if pref_data==1, fast absorb(`routeFE' countryb weekstarttrip divisionid) vce(cluster countryb)
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1

foreach pref in patience risktaking altruism posreciprocity negreciprocity trust {
timer on 1
eststo: reghdfe `outcomevar' female f`pref' i.ntripb i.ageb `ticketcov' i.emptyp if pref_data==1, fast absorb(`routeFE' countryb weekstarttrip divisionid) vce(cluster countryb)
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
}
esttab, se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype)
esttab using "$dir/Tables/Table_`outcomevar'_prefint_v2`testing'.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
    title(`outcomename': Gender-Preference interactions\label{tab`outcomevar'}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype)
eststo clear
log close
