require(dplyr)
require(lfe)

trips_per_port2 <- routes_data %>%
  count(o_d_airport) %>%
  rename('trips_per_od'=n)

trips_per_od_75th <- quantile(trips_per_port2$trips_per_od, probs = 0.75)

routes_data_drpd <- routes_data %>%
  left_join(trips_per_port2, by=c('o_d_airport')) %>%
  filter(trips_per_od>trips_per_od_75th)

routes_data_drpd <- routes_data_drpd %>% 
  group_by(o_d_airport) %>%
  mutate(
    problem = ifelse(any(tabulate(ticketclass)==0), 1, 0),
    od_recode = ifelse(problem==1, 'BAD', o_d_airport)
  ) %>% 
  ungroup()

routes_data_drpd$od_recode <- routes_data_drpd$od_recode %>% as.factor() %>% relevel(., ref='BAD')

list_of_specification_names <- c(
  'pf_c_od_wk_cntry_comp_trav_div_dropped', 'pf_c_odtkt_wk_cntry_comp_trav_div_dropped'
)

models <- list(
  paste("paid_fare_usd ~ + female + ", controls, "|  od_recode:as.factor(ticketclass) + as.factor(weekstarttrip) + issuing_country + trav_class_2 + as.factor(divisionid)") %>% as.formula(),
  paste("paid_fare_usd ~ + female + bk_adv_bins_26 + ", controls, "| od_recode:as.factor(ticketclass) + as.factor(weekstarttrip) + issuing_country + trav_class_2 + as.factor(divisionid)") %>% as.formula()
)

for(i in 1:length(models)){
  try(
    estimate_and_save(list_of_specification_names[i], 'TableDropODpf', formula = models[[i]], data = routes_data_drpd)
  )
}