clear all
set more off
capture log close
local estoutcome = 1
global dir 		"/DV-Gender-Differences/Travel-Patterns"
use "$dir/booking_ana_data_v2.dta"
*sample 1
g startdatef  = date(startdate, "YMD")
format %td startdatef
g enddatef  = date(enddate, "YMD")
format %td enddatef
g startmonth=month(startdatef)
g endmonth=month(enddatef)
* Drop Nov or Dec
preserve
drop if startmonth>=11 | endmonth>=11

local ticketcov "i.lengthb direct"
local ticketcovdrop "*.lengthb direct"
local routeFE "routeclass"
if (`estoutcome'==1) {
 local outcomevar paid_fare_usd
 local outcomename "Paid fare"
}
log using "$dir/log_ana_`outcomevar'_v2`testing'-vacation", text replace
timer on 1
reghdfe `outcomevar' female `ticketcov', absorb(`routeFE' weekstarttrip divisionid countryb)
eststo est3
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
capture drop sample
gen sample = e(sample)
tab sample

reg `outcomevar' female if sample==1
eststo est1
quietly estadd scalar adjR2 = e(r2_a)

timer on 1
reghdfe `outcomevar' female `ticketcov' if sample==1,   absorb(`routeFE' weekstarttrip)
eststo est2
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1

timer on 1
reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1,   absorb(`routeFE' weekstarttrip divisionid countryb) 
eststo est4
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
local estlist "est1 est2 est3 est4"
if ((`estoutcome'<2)|(`estoutcome'>6)) {
 timer on 1
 reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1,   absorb(`routeFE' weekstarttrip divisionid countryb bookbin)
 eststo est5
 quietly estadd scalar adjR2 = e(r2_a)
 timer off 1
 timer list 1
 timer clear 1
 local estlist "est1 est2 est3 est4 est5"
}
esttab `estlist', se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
esttab `estlist' using "$dir/Tables/Table_`outcomevar'_v2`testing'-vacation.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
    title(`outcomename' by Gender\label{tab`outcomevar'}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
    eststo clear

restore
log close

* Just US
preserve
keep if country_code=="US"
local ticketcov "i.lengthb direct"
local ticketcovdrop "*.lengthb direct"
local routeFE "routeclass"
if (`estoutcome'==1) {
 local outcomevar paid_fare_usd
 local outcomename "Paid fare"
}
log using "$dir/log_ana_`outcomevar'_v2`testing'-US-YesThanks", text replace
timer on 1
reghdfe `outcomevar' female `ticketcov', absorb(`routeFE' weekstarttrip divisionid countryb)
eststo est3
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
capture drop sample
gen sample = e(sample)
tab sample

reg `outcomevar' female if sample==1
eststo est1
quietly estadd scalar adjR2 = e(r2_a)

timer on 1
reghdfe `outcomevar' female `ticketcov' if sample==1,   absorb(`routeFE' weekstarttrip)
eststo est2
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1

timer on 1
reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1,   absorb(`routeFE' weekstarttrip divisionid countryb) 
eststo est4
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
local estlist "est1 est2 est3 est4"
if ((`estoutcome'<2)|(`estoutcome'>6)) {
 timer on 1
 reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1,   absorb(`routeFE' weekstarttrip divisionid countryb bookbin)
 eststo est5
 quietly estadd scalar adjR2 = e(r2_a)
 timer off 1
 timer list 1
 timer clear 1
 local estlist "est1 est2 est3 est4 est5"
}
esttab `estlist', se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
esttab `estlist' using "$dir/Tables/Table_`outcomevar'_v2`testing'-US-YesThanks.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
    title(`outcomename' by Gender\label{tab`outcomevar'}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
    eststo clear

log close
* US without Thanksgiving week
* Thanksgiving week: weeks of Nov 23 to Nov 30 (2014)
g 		thank_week=(startdatef>=20050 & startdatef<=20057)
replace thank_week=1 if endmonth>=20050 & endmonth<=20057
drop if thank_week==1

local ticketcov "i.lengthb direct"
local ticketcovdrop "*.lengthb direct"
local routeFE "routeclass"
if (`estoutcome'==1) {
 local outcomevar paid_fare_usd
 local outcomename "Paid fare"
}
log using "$dir/log_ana_`outcomevar'_v2`testing'-US-NoThanks", text replace
timer on 1
reghdfe `outcomevar' female `ticketcov', absorb(`routeFE' weekstarttrip divisionid countryb)
eststo est3
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
capture drop sample
gen sample = e(sample)
tab sample

reg `outcomevar' female if sample==1
eststo est1
quietly estadd scalar adjR2 = e(r2_a)

timer on 1
reghdfe `outcomevar' female `ticketcov' if sample==1,   absorb(`routeFE' weekstarttrip)
eststo est2
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1

timer on 1
reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1,   absorb(`routeFE' weekstarttrip divisionid countryb) 
eststo est4
quietly estadd scalar adjR2 = e(r2_a)
timer off 1
timer list 1
timer clear 1
local estlist "est1 est2 est3 est4"
if ((`estoutcome'<2)|(`estoutcome'>6)) {
 timer on 1
 reghdfe `outcomevar' female `ticketcov' i.ntripb i.ageb i.emptype if sample==1,   absorb(`routeFE' weekstarttrip divisionid countryb bookbin)
 eststo est5
 quietly estadd scalar adjR2 = e(r2_a)
 timer off 1
 timer list 1
 timer clear 1
 local estlist "est1 est2 est3 est4 est5"
}
esttab `estlist', se label stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
esttab `estlist' using "$dir/Tables/Table_`outcomevar'_v2`testing'-US-NoThanks.tex", se label nogaps booktabs ///
        stats(adjR2 N, labels("Adjusted \$R^2$" "Number of Observations")) ///
    title(`outcomename' by Gender\label{tab`outcomevar'}) replace drop(*.ntripb *.ageb `ticketcovdrop' *.emptype *cons)
    eststo clear
restore
log close
